- folder
Full folder path or folder path relative to the current working
directory that holds the image chips and associated masks. You must include
the final forward slash in the folder path (e.g., "C:/data/chips/").
- extension
Raster file extension (e.g., ".tif", ".png", ".jpeg", or ".img").
The utilities in this package generate files in ".tif" format, so this is the default.
This option is provided if chips are generated using another method.
- mode
Either "All", "Positive", or "Divided". This should match the settings
used in the makeChips() function or be set to "All" if makeChipsMultiClass() is
used. Default is "All".
- subSample
TRUE or FALSE. Whether or not to subsample the image chips to
calculate the summary metrics. We recommend using a subset if a large set of
chips are being summarized to reduce computational load. The default is TRUE.
- numChips
If subSample is set to TRUE, this parameter defines the
number of chips to subset. The default is 200. This parameter will be ignored
if subSample is set to FALSE.
- numChipsBack
If subSample is set to TRUE and the mode is "Divided", this
parameter indicates the number of chips to sample from the background-only
samples. The default is 200. This parameter will be ignored if subSample is
set to FALSE and/or mode is not "Divided".
- subSamplePix
TRUE or FALSE. Whether or not to calculate statistics using
a subsample of pixels from each image chip as opposed to all pixels. If a large
number of chips are available and/or each chip is large, we suggest setting this
argument to TRUE to reduce the computational load. The default is TRUE.
- sampsPerChip
If subSamplePix is TRUE, this parameters specifies the
number of random pixels to sample per chip. The default is 100. If
subSamplePix is set to FALSE, this parameter is ignored.